# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.2.1] - 2023-07-18
### Changed
- Updated `qrlew-datasets`

## [0.2.0] - 2023-07-18
### Changed
- Remove data and db from pyqrlew. They are now in the qrlew-dataset package.
- The example notebook has been updated.

## [0.1.0] - 2023-07-11

### Added

- Changelog file

### Fixed

- Automated Postgresql setup if not already the case

### Changed

- Upgrade dependencies: Ruby 3.2.1, Middleman, etc.

### Removed

- Cleaned the test environment
